=========
FireWorks
=========

FireWorks helps run calculation workflows, with a centralized workflow server controlling many worker nodes.

For more about FireWorks, please visit the official documentation_.

The best place to get help is the Google group (here_).

.. _documentation: http://packages.python.org/FireWorks/
.. _here: https://groups.google.com/forum/#!forum/fireworkflows